InteractiveButtons = {};

function InteractiveButtons.prerequisitesPresent(specializations)
	if not SpecializationUtil.hasSpecialization(InteractiveControl, specializations) then print("Warning: Specialization InteractiveButtons v3.1.1 needs the specialization InteractiveControl v4.1"); end;
    return SpecializationUtil.hasSpecialization(InteractiveControl, specializations);
end;

function InteractiveButtons:load(savegame)

	local i=0;
	while true do
		local buttonName = string.format("vehicle.interactiveComponents.buttons.button(%d)", i);	
		if not hasXMLProperty(self.xmlFile, buttonName) then
			break;
		end;
		local name = Utils.getNoNil(g_i18n:getText(getXMLString(self.xmlFile, buttonName .. "#name")), "ERROR");
		local mark = Utils.indexToObject(self.components, getXMLString(self.xmlFile, buttonName .. "#mark"));
		local highlight = getChildAt(mark, 0);
		local size = Utils.getNoNil(getXMLFloat(self.xmlFile, buttonName .. "#size"), 0.1);
		local event = getXMLString(self.xmlFile, buttonName .. "#event");
		local onMessage = g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, buttonName .. "#onMessage"), "action_turnOnOBJECT"));
		local offMessage =  g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, buttonName .. "#offMessage") , "action_turnOffOBJECT"));
		
		local playBcSound = Utils.getNoNil(getXMLBool(self.xmlFile, buttonName .. "#playClickSound"), false);
	
		local button = Button:new(nil, highlight, name, mark, size, event, self, onMessage, offMessage, playBcSound);
		
		button.synch = Utils.getNoNil(getXMLBool(self.xmlFile, buttonName .. "#synch"), true);

		table.insert(self.interactiveObjects, button);
		i = i + 1;
	end;
	
end;

function InteractiveButtons:delete()
end;

function InteractiveButtons:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveButtons:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveButtons:update(dt)	
end;

function InteractiveButtons:draw()
end;

Button = {};

function Button:new(node, highlight, name, mark, size, event, vehicle, onMessage, offMessage, playBcSound)

	local Button_mt = Class(Button, InteractiveComponentInterface);	
    local instance = InteractiveComponentInterface:new(node, highlight, name, mark, size, onMessage, offMessage, Button_mt);

	instance.vehicle = vehicle;
	instance.event = event;
	instance.playBcSound = playBcSound
	
	return instance;	
end;

function Button:delete()
	InteractiveComponentInterface.delete(self);
end;

function Button:mouseEvent(posX, posY, isDown, isUp, button)
	InteractiveComponentInterface.mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function Button:keyEvent(unicode, sym, modifier, isDown)
	InteractiveComponentInterface.keyEvent(self, unicode, sym, modifier, isDown);
end;

function Button:update(dt)
	if self.vehicle ~= nil then
		if self.event == "LigarMotor" then		
			self.isOpen = self.vehicle.isMotorStarted;
		end;
	end;
	
	if self.vehicle ~= nil then
		if self.event == "LuzWarnings" then
			self.isOpen = self.vehicle.turnLightState == Lights.TURNLIGHT_HAZARD;
		end;
	end;
	
	
	
	
	
	if self.vehicle ~= nil then
		if self.event == "VelocidadeCruzeiro" then
			self.isOpen = self.vehicle.cruiseControl.state == Drivable.CRUISECONTROL_STATE_ACTIVE;
		end;
	end;
	if self.vehicle ~= nil then
		if self.event == "AugmentarVelocidadeCruzeiro" then
			local single = false
			self.isOpen = self.vehicle.cruiseControl.speed == self.vehicle.cruiseControl.maxSpeed
		end;
	end;
	if self.vehicle ~= nil then
		if self.event == "DiminuirVelocidadeCruzeiro" then
			self.isOpen = self.vehicle.cruiseControl.speed == self.vehicle.cruiseControl.minSpeed
		end;
	end;

	InteractiveComponentInterface.update(self, dt);
end;

function Button:draw()
	InteractiveComponentInterface.draw(self);
end;

function Button:doAction(noEventSend, forceAction)
	InteractiveComponentInterface.doAction(self, forceAction);
	
	if self.vehicle ~= nil then
		if self.playBcSound ~= nil and self.vehicle:getIsActiveForSound() then
			if self.playBcSound then
				SoundUtil.playSample(g_currentMission.sampleToggleLights, 1, 0, 1);
			end;
		end;
	end;
	
	
	if self.vehicle ~= nil then		
		if self.event == "LigarMotor" then
			if forceAction == nil then
				if not g_currentMission.missionInfo.automaticMotorStartEnabled then
					if self.vehicle.isMotorStarted then
						self.vehicle:stopMotor();
					else
						self.vehicle:startMotor();
					end;
				end;
			end;
		end;	
	end;
	
	if self.vehicle ~= nil then
		if self.event == "LuzWarnings" then
			if forceAction == nil then
			local state = Lights.TURNLIGHT_OFF;
                if self.vehicle.turnLightState ~= Lights.TURNLIGHT_HAZARD then
                    state = Lights.TURNLIGHT_HAZARD;
                end
                self.vehicle:setTurnLightState(state);
			end;
		end;
	end;
	
	if self.vehicle ~= nil then
		if self.event == "VelocidadeCruzeiro" then
			if forceAction == nil then
				if self.vehicle.cruiseControl.state == Drivable.CRUISECONTROL_STATE_OFF then
                    self.vehicle:setCruiseControlState(Drivable.CRUISECONTROL_STATE_ACTIVE);
                else
                    self.vehicle:setCruiseControlState(Drivable.CRUISECONTROL_STATE_OFF);
                end;
			end;
		end;
	end;
	if self.vehicle ~= nil then
		if self.event == "AugmentarVelocidadeCruzeiro" then
			if forceAction == nil then
				self.vehicle:setCruiseControlMaxSpeed(self.vehicle.cruiseControl.speed + 1);
			end;
		end;
	end;
	if self.vehicle ~= nil then
		if self.event == "DiminuirVelocidadeCruzeiro" then
			if forceAction == nil then
				self.vehicle:setCruiseControlMaxSpeed(self.vehicle.cruiseControl.speed - 1);
			end;
		end;
	end;
	
end;

function Button:onEnter(dt)
	InteractiveComponentInterface.onEnter(self, dt);
end;

function Button:onExit(dt)
	InteractiveComponentInterface.onExit(self, dt);
end;

function Button:setActive()
	InteractiveComponentInterface.setActive(self, isActive);
end;

function Button:setVisible(isVisible)
	InteractiveComponentInterface.setVisible(self, isVisible);
end;